@@ -83,8 +83,8 @@ class MyWorkspacesDisplay extends WorkspacesDisplay {
         this._workareasChangedId = 0;
 
         if (this._nWorkspacesChangedId)
-            global.workspace_manager.disconnect(this._nWorkspacesNotifyId);
-        this._nWorkspacesNotifyId = 0;
+            global.workspace_manager.disconnect(this._nWorkspacesChangedId);
+        this._nWorkspacesChangedId = 0;
 
         super._onDestroy();
     }
@@ -286,8 +286,6 @@ class WindowPickerToggle extends St.Button {
             style_class: 'window-picker-toggle',
             child: iconBin,
             visible: !Main.sessionMode.hasOverview,
-            x_fill: true,
-            y_fill: true,
             toggle_mode: true,
         });
 
